#!/usr/bin/perl
#=======================================================================
# FileName : cmd_GetAileProductInfo.pl
# Summary  : Aileun製品情報取得ベースコマンド
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/02/24 Kiyoshi Oishi      Initial Release
#=======================================================================
use strict;
use JSON;
use Encode;
use Data::Dumper;

use lib '../com-lib';
use ComConst;
use ComFunc;
use CmdComFunc;
use ComLog;

our %messages = ();
my $ret = ComConst::STS_OK;

$ret = &main(@ARGV);

exit $ret;

#=======================================================================
# FuncName : main
# Summary  : Aileun製品情報取得メイン処理
# Argument : (IN)  $reqFile  : リクエストファイル名(scalar)
#          : (IN)  $resFile  : レスポンスファイル名(scalar)
# Return   : 正常:0, 異常:-1
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/02/24 Kiyoshi Oishi      Initial Release
#=======================================================================
sub main {
    my $rc = ComConst::STS_OK;
    my $reqFile   = $_[0];
    my $resFile   = $_[1];
    my $requestData = "";
    my $json = "";
    my %responseData = ();
    my %conf      = ();
    my $logLevel = "";
    my $logmsg = "";
    $responseData{ComConst::JSON_KEY_STS} = ComConst::STS_OK;
    $responseData{ComConst::JSON_KEY_MSG} = "";
    $responseData{ComConst::JSON_KEY_DAT} = ();
    my $key = "";

    # 初期化
    if($rc == ComConst::STS_OK){
        $rc = CmdComFunc::initializeBaseCmd($0, \%conf, \%messages);
    }

    # 開始ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D001});

    # リクエスト読み込み
    if($rc == ComConst::STS_OK){
        $requestData = CmdComFunc::readRequestFile($reqFile);
    }

    # 入力チェック
    if($rc == ComConst::STS_OK){
         # 入力はないので処理なし
    }

    # データ作成
    if($rc == ComConst::STS_OK){
        # Aileunのバージョン番号を取得
        $responseData{ComConst::JSON_KEY_DAT}{ProductInfo}{AileFirmVersion} = getAileFirmVersion();
        # Aileunの製品番号情報を取得
        my $productNo = getAileProductNo();
        $responseData{ComConst::JSON_KEY_DAT}{ProductInfo}{AileProductNo} = $productNo;
        # Aileunのカメラ台数情報を取得
        $responseData{ComConst::JSON_KEY_DAT}{ProductInfo}{AileCameraNum} = getAileCameraNumber($productNo);
        # Aileunの特別設定
        $responseData{ComConst::JSON_KEY_DAT}{ProductInfo}{AileSpecialConfig} = getAileSpecialConfigKey();
    }

    # レスポンスファイル出力
    $rc = CmdComFunc::writeResponseFile($resFile, \%responseData);

    # 終了ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D002});

    return $rc;
}

#=======================================================================
# FuncName : getAileFirmVersion
# Summary  : Aileunバージョン番号取得
# Argument : Nothing
# Return   : バージョン番号
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/02/27 Kiyoshi Oishi      Initial Release
#=======================================================================
sub getAileFirmVersion {
    my $version = "";
    my $exec_cmd = sprintf(ComConst::GET_AILEUN_VERSION_CMD, ComConst::AILEUN_VERSION_FILE);

    chomp($version = `$exec_cmd`);

    return $version;
}

#=======================================================================
# FuncName : getAileProductNo
# Summary  : Aileun製品番号取得
# Argument : Nothing
# Return   : 製品番号
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/02/27 Kiyoshi Oishi      Initial Release
#=======================================================================
sub getAileProductNo {
    my $prdctNo = "";
    my $exec_cmd = sprintf(ComConst::GET_AILEUN_PRDCTNO_CMD, ComConst::AILEUN_PRDCTNO_FILE);

    chomp($prdctNo = `$exec_cmd`);

    return $prdctNo;
}

#=======================================================================
# FuncName : getAileCameraNumber
# Summary  : Aileunカメラ台数取得
# Argument : Nothing
# Return   : カメラ台数
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/02/27 Kiyoshi Oishi      Initial Release
#=======================================================================
sub getAileCameraNumber {
    my $productNo = $_[0];
    my $cameraNum = $ComConst::HwType2CamNum->{$ComConst::Product2HwType->{$productNo}};

    return $cameraNum;
}

#=======================================================================
# FuncName : getAileSpecialConfig
# Summary  : Aileun特別設定取得
# Argument : Nothing
# Return   : 特別設定情報
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/02/27 Kiyoshi Oishi      Initial Release
#=======================================================================
sub getAileSpecialConfigKey {
    return ComConst::SPECIAL_CONFIG_N;
}
