#!/usr/bin/perl
#=======================================================================
# FileName : AileHttpAlarm.pl
# Summary  : TOAアラーム通知API
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2018/06/01 Kiyoshi Oishi      Initial Release
#=======================================================================
use strict;
use CGI;
use JSON;
use Data::Dumper;

use lib '../com-lib';
use ComConst;
use ComFunc;
use ComLog;

my $rc = ComConst::STS_OK;

$rc = &main();

#=======================================================================
# FuncName : main
# Summary  : 再起動メイン処理
# Argument : (IN)  $reqFile  : リクエストファイル名(scalar)
#          : (IN)  $resFile  : レスポンスファイル名(scalar)
# Return   : 正常:0, 異常:-1
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2018/06/01 Kiyoshi Oishi      Initial Release
#=======================================================================
sub main {
    my $rc = ComConst::STS_OK;
    my %conf = ();
    my %messages = ();
    my $cgi = new CGI;
    my %request = ();
    my %res_data = (ComConst::JSON_KEY_STS=>ComConst::STS_OK, ComConst::JSON_KEY_MSG=>"");
    my $resData = "";
    my $header = "";
    my $cmdData  = "";

    # 初期化処理
    if($rc == ComConst::STS_OK){
        $rc = ComFunc::initializeApi($0, \%conf, \%messages);
    }

    # 開始ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D001});

    # リクエストデータの取得
    if($rc == ComConst::STS_OK){
        $rc = ComFunc::getCtrlAipRequestData(\$cgi, \%request);
        if($rc != ComConst::STS_OK){
            $res_data{ComConst::JSON_KEY_STS} = ComConst::STS_NG;
        }
    }
    
    # リクエストデータ
    ComLog::log_output(ComLog::LOG_DEBUG, Dumper(\%request));

    # リクエストパラメータチェック
    if ($rc == ComConst::STS_OK) {
        foreach my $key (keys(%$ComConst::HTTP_REQUEST_KEYS)) {
            if (!defined($request{$key})) {
                $rc = ComConst::STS_NG;
                last;
            }
            if (defined($$ComConst::HTTP_REQUEST_KEYS{$key}->{range})) {
                if ($request{$key} < $$ComConst::HTTP_REQUEST_KEYS{$key}->{range}->[0] || $request{$key} > $$ComConst::HTTP_REQUEST_KEYS{$key}->{range}->[1]) {
                    $rc = ComConst::STS_NG;
                    last;
                }
            }
            # Viewerは0〜15なので指定された番号-1しておく
            $request{$key} = $request{$key} - 1;
        }
        if ($rc != ComConst::STS_OK) {
            $res_data{ComConst::JSON_KEY_STS} = $rc;
            $res_data{ComConst::JSON_KEY_MSG} = $messages{CM004E001};
        }
    }

    # リクエストデータ作成
    if($rc == ComConst::STS_OK){
        $cmdData = ComConst::HTTP_ALARM_DATATEMPLATE;
        foreach my $key (keys(%$ComConst::HTTP_REQUEST_KEYS)) {
            $cmdData =~ s/\$<$key>/$request{$key}/g;
        }
    }

    # リクエストデータをファイルに出力
    if($rc == ComConst::STS_OK){
        $rc = ComFunc::writeRequestFile($conf{JSON_FILE}->{REQUEST}, {data=>$cmdData});
        if($rc != ComConst::STS_OK){
            $res_data{ComConst::JSON_KEY_STS} = ComConst::STS_NG;
        }
    }

    # コマンドを呼び出し
    if($rc == ComConst::STS_OK){
        $rc = `$conf{EXEC_CMD} $conf{JSON_FILE}->{REQUEST} $conf{JSON_FILE}->{RESPONSE}`;
        if($rc != ComConst::STS_OK){
            $res_data{ComConst::JSON_KEY_STS} = ComConst::STS_NG;
        }
    }

    # 結果ファイルを読込む
    $resData = ComFunc::readResponseFile($conf{JSON_FILE}->{RESPONSE}, \%res_data);
    ComLog::log_output(ComLog::LOG_DEBUG, Dumper($resData));

    # リクエストファイルとレスポンスファイルを削除
    ComFunc::rmJsonFile($conf{JSON_FILE});

    # 結果を返す
    $header = $cgi->header(-type=>'application/json', -charset=>'UTF-8');
    ComFunc::setResponsData($resData, $header);

    # 終了ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D002});

    return $rc;
}
