#!/usr/bin/perl
#=======================================================================
# FileName : execSystemOperate.pl
# Summary  : システム操作API
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/03/09 Kiyoshi Oishi      Initial Release
#=======================================================================
use strict;
use CGI;
use JSON;
use Data::Dumper;

use lib '../com-lib';
use ComConst;
use ComFunc;
use ComLog;

my $rc = ComConst::STS_OK;

$rc = &main();

exit $rc;

#=======================================================================
# FuncName : main
# Summary  : システム操作メイン処理
# Argument : (IN)  $reqFile  : リクエストファイル名(scalar)
#          : (IN)  $resFile  : レスポンスファイル名(scalar)
# Return   : 正常:0, 異常:-1
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/03/09 Kiyoshi Oishi      Initial Release
#=======================================================================
sub main {
    my $rc = ComConst::STS_OK;
    my %conf = ();
    my %messages = ();
    my $cgi = new CGI;
    my %request = ();
    my %res_data = (ComConst::JSON_KEY_STS=>ComConst::STS_OK, ComConst::JSON_KEY_MSG=>"");
    my $resData = "";
    my $header = "";

    # 初期化処理
    if($rc == ComConst::STS_OK){
        $rc = ComFunc::initializeApi($0, \%conf, \%messages);
    }

    # 開始ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D001});

    # リクエストデータの取得
    if($rc == ComConst::STS_OK){
        $rc = ComFunc::getRequestData(\$cgi, \%request);
        if($rc != ComConst::STS_OK){
            $res_data{ComConst::JSON_KEY_STS} = ComConst::STS_NG;
        }
    }

    # リクエストデータをファイルに出力
    if($rc == ComConst::STS_OK){
        $rc = ComFunc::writeRequestFile($conf{JSON_FILE}->{REQUEST}, \%request);
        if($rc != ComConst::STS_OK){
            $res_data{ComConst::JSON_KEY_STS} = ComConst::STS_NG;
        }
    }

    # コマンドを呼び出し
    if($rc == ComConst::STS_OK){
        $rc = `$conf{EXEC_CMD} $conf{JSON_FILE}->{REQUEST} $conf{JSON_FILE}->{RESPONSE}`;
        if($rc != ComConst::STS_OK){
            $res_data{ComConst::JSON_KEY_STS} = ComConst::STS_NG;
        }
    }

    # 結果ファイルを読込む
    $resData = ComFunc::readResponseFile($conf{JSON_FILE}->{RESPONSE}, \%res_data);
    ComLog::log_output(ComLog::LOG_DEBUG, Dumper($resData));

    # リクエストファイルとレスポンスファイルを削除
    ComFunc::rmJsonFile($conf{JSON_FILE});

    # 結果を返す
    $header = $cgi->header(-type=>'application/json', -charset=>'UTF-8');
    ComFunc::setResponsData($resData, $header);

    # 終了ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D002});

    return $rc;
}
